Dummy
======

This workspace contains the basic tasks for provisioning and teardown of dummy clusters.

As the name implies, dummy clusters do not provision any resources, but do run through
the provisioning steps for easy testing of linchpin features

dummy-new
========
Porivions  a new set of dummy resources and creates a layout to go with them.  The name of the inventory file is dynamically generated based on the uhash

dummy-topo
========
Another set of dummy resources with a slightly simpler layout
